<?php 
/**
 *
 * プラグインに必要な設定
 *
 * @since   1.0.0
 * @package stile-blocks
 */

defined( 'ABSPATH' ) || exit;

/**
 * javascript・CSSの読み込み
 *
 * @since 1.0.0
 * @return void
 */
function stlbl_gutenberg_register_block() {

  if ( ! function_exists( 'register_block_type' ) ) {
    return;
  }

  wp_register_script(
    'script-stile-blocks',
    plugins_url( 'build/block.js', __FILE__ ),
    array( 'wp-blocks', 'wp-editor', 'wp-element', 'wp-components', 'wp-rich-text' ),
    STLBL_VERSION
  );

  wp_register_script(
    'script-stile-blocks-toolbar',
    plugins_url( 'build/toolbar.js', __FILE__ ),
    array( 'wp-blocks', 'wp-editor', 'wp-element', 'wp-components', 'wp-rich-text' ),
    STLBL_VERSION
  );

  wp_register_style(
    'editor-style-stile-blocks',
    plugins_url( 'build/editor.css', __FILE__ ),
    array( 'wp-edit-blocks' ),
    STLBL_VERSION
  );

  register_block_type( 'stile-blocks/stile-blocks', array(
    'editor_script' => array( 'script-stile-blocks','script-stile-blocks-toolbar' ),
    'editor_style' => 'editor-style-stile-blocks',
  ) );

  register_block_type( 'stile-blocks/related-post', array(
    'editor_script' => array( 'script-stile-blocks','script-stile-blocks-toolbar' ),
    'editor_style' => 'editor-style-stile-blocks',
    'attributes' => array(
      'postTitle'   => array(
        'type' => 'string',
        'default' => '',
      ),
      'postId'    => array(
        'type' => 'string',
        'default' => '',
      ),
      'isNewTab'    => array(
        'type' => 'boolean',
        'default' => !1,
      ),
      'cardCaption' => array(
        'type' => 'string',
        'default' => '',
      ),
    ),
    'render_callback'=> 'stlbl_get_post_link_callback',
  ) );

  wp_localize_script( 'script-stile-blocks', 'stileBlocks', array(
    'srcUrl' => untrailingslashit( plugins_url( 'build//', __FILE__ ) ),
  ) );

}
add_action( 'init', 'stlbl_gutenberg_register_block' );

function stlbl_plugin_load_src() {
  $is_inline = !empty( get_option( 'stl_css_inline' ) ) ? true : false;

  if( $is_inline ) {
    ob_start();
    require_once( dirname( __FILE__ ) . '/build/style.css' );
    $style = ob_get_contents();
    ob_end_clean();
    
    wp_register_style( 'style-stile-blocks', false );
    wp_enqueue_style( 'style-stile-blocks' );
    wp_add_inline_style( 'style-stile-blocks', $style );
  } else {
    wp_register_style(
      'style-stile-blocks',
      plugins_url( 'build/style.css',__FILE__ ),
      array(),
      STLBL_VERSION
    );
    wp_enqueue_style( 'style-stile-blocks' );
  }
  wp_enqueue_script( 'scripts-stile-blocks', plugins_url( 'build/script.js', __FILE__ ), array(), STLBL_VERSION, 'true' );
}
add_action('wp_enqueue_scripts', 'stlbl_plugin_load_src');

/**
 * 投稿ページでFontAwesomeを読み込む
 * @since 1.0.0
 * @return void
 */
if ( ! function_exists( 'stlbl_add_admin_inline_style' ) ) {
  function stlbl_add_admin_inline_style() {
    echo '<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.11.2/css/all.min.css" integrity="sha256-+N4/V/SbAFiW1MPBCXnfnP9QSN3+Keu+NlB+0ev/YKQ=" crossorigin="anonymous" />'.PHP_EOL;
  }
  add_action('admin_print_styles', 'stlbl_add_admin_inline_style');
}

/**
 * 関連記事用ブログカード
 * @since 1.1.0
 * @return string
 */
function stlbl_get_post_link_callback( $args) {
  if ( empty( $args['postId'] ) ) return "";
  $post_id   = $args['postId'];
  $post_data = get_post( $post_id );
  $title     = get_the_title( $post_id );
  $url       = get_permalink( $post_id );
  $excerpt   = stlbl_get_post_excerpt( $post_data, 60 );

  if ( mb_strwidth( $title, 'UTF-8' ) > 100 ) {
    $title = mb_strimwidth($title, 0, 100, '...', 'UTF-8');
  }
  $title = esc_html($title);
  $thumb_src = "";
  $thumb_src = stlbl_get_thumbnail_url( $post_id, 'thumbnail' );
  if(!empty($thumb_src)){
    $content_thumb = '<div class="stlbl-relatedpost__thumb"><figure class="stlbl-relatedpost__thumb_inner"><img src="'.$thumb_src.'" alt="'.$title.'"></figure></div>';
  }else{
    $content_thumb = '<div class="stlbl-relatedpost__thumb"><span class="stlbl-relatedpost__thumb_inner stlbl-relatedpost__thumb_inner--noimage"></span></div>';
  }
  return '<div class="stlbl-relatedpost"><a href="'.$url.'" class="stlbl-relatedpost__blogcard customize-text-color hover-customize-main-color">'.
  $content_thumb .
  '<div class="stlbl-relatedpost__content"><span class="stlbl-relatedpost__ttl">'.$title.'</span><span class="stlbl-relatedpost__txt">'.$excerpt.'</span></div>'.
  '</a></div>';
}

/**
 * 本文抜粋
 * @since 1.1.0
 * @return string
 */
function stlbl_get_post_excerpt( $post_data = null, $length = null ) {
  $length = $length ?: 30;
  if ( $length === 0 ) {
    return "";
  }
  if ( ! empty( $post_data->post_excerpt ) ) {
    $excerpt = strip_tags( $post_data->post_excerpt );
  } elseif ( !empty( $post_data->post_password ) ) {
    $excerpt = 'この記事はパスワードで保護されています。';
  } else {
    $excerpt = strip_shortcodes( $post_data->post_content );
    $excerpt = strip_tags( $excerpt );
    $excerpt = str_replace( array( "\r\n", "\r", "\n" ), '', $excerpt );
    if ( mb_strwidth( $excerpt, 'UTF-8' ) > $length * 2  ) {
      $excerpt = mb_strimwidth( $excerpt, 0, $length * 2 , '...', 'UTF-8' );
    }
  }
  return $excerpt;
}

/**
 * オリジナルのカスタムブロックを追加
 *
 * @since 1.0.0
 * @return void
 */
if ( ! function_exists( 'stlbl_gutenberg_register_block_category' ) ) {
  function stlbl_gutenberg_register_block_category( $categories ) {
    $categories[] = [
      'slug'  => 'stlbl_block',
      'title' => '【stile】カスタムブロック'
    ];
    return $categories;
  }
  add_filter( 'block_categories', 'stlbl_gutenberg_register_block_category' );
}

if ( ! function_exists( 'stlbl_add_js_settings' ) ) {
  function stlbl_add_js_settings() {
    /**
     * 吹き出し管理の設定を取得
     */
    $fukidashi_sets = array();
    $args = array(
      'post_type' => 'fukidashi',
      'posts_per_page' => -1
    );
    $fukidashi_posts = get_posts( $args );

    if( $fukidashi_posts ) {
      foreach( $fukidashi_posts as $post ) {
        $id = $post->ID;
        $fukidashi_title = get_the_title( $id );
        $fukidashi_image = get_post_meta( $id, 'fukidashi_image', true );
        $fukidashi_name = get_post_meta( $id, 'fukidashi_name', true );
 
        $fukidashi_sets[$id] = array(
          'title' => $fukidashi_title,
          'image' => $fukidashi_image,
          'name' => $fukidashi_name,
        );
        
      }
    }
    wp_reset_postdata();

    $json = json_encode( $fukidashi_sets );

    echo '<script>window.stileSetsFukidashi = ' . $json . '</script>' . PHP_EOL;
    
  }
  add_action('admin_print_scripts', 'stlbl_add_js_settings');
}